==> arquillian-container-spi-1.1.12.Final-sources.jar: org/jboss/arquillian/container/spi/event/container/ContainerEvent.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2009 Red Hat Inc. and/or its affiliates and other contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.container.spi.event.container;

import org.jboss.arquillian.container.spi.client.container.DeployableContainer;
import org.jboss.arquillian.core.spi.Validate;
import org.jboss.arquillian.core.spi.event.Event;

/**
 * Base for events fired in the Container life cycle
 *
 * @author <a href="mailto:aknutsen@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 */
public class ContainerEvent implements Event
{
   private DeployableContainer<?> deployableContainer;
   
   public ContainerEvent(DeployableContainer<?> deployableContainer)
   {
      Validate.notNull(deployableContainer, "DeployableContainer must be specified");
      this.deployableContainer = deployableContainer;
   }
   
   /**
    * @return the deployableContainer
    */
   public DeployableContainer<?> getDeployableContainer()
   {
      return deployableContainer;
   }
}

==> arquillian-container-spi-1.4.1.Final-sources.jar: org/jboss/arquillian/container/spi/event/container/ContainerEvent.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2009 Red Hat Inc. and/or its affiliates and other contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.container.spi.event.container;

import org.jboss.arquillian.container.spi.client.container.DeployableContainer;
import org.jboss.arquillian.core.spi.Validate;
import org.jboss.arquillian.core.spi.event.Event;

/**
 * Base for events fired in the Container life cycle
 *
 * @author <a href="mailto:aknutsen@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 */
public class ContainerEvent implements Event {
    private DeployableContainer<?> deployableContainer;

    public ContainerEvent(DeployableContainer<?> deployableContainer) {
        Validate.notNull(deployableContainer, "DeployableContainer must be specified");
        this.deployableContainer = deployableContainer;
    }

    /**
     * @return the deployableContainer
     */
    public DeployableContainer<?> getDeployableContainer() {
        return deployableContainer;
    }
}
